==> webmin-0.79.tar.gz: webmin-0.79/apache/mod_env.pl <==
# mod_env.pl
# Defines editors for passing variables to CGI scripts

sub mod_env_directives
{
local($rv);
$rv = [ [ 'PassEnv UnsetEnv SetEnv', 1, 11, 'virtual', -1.309 ],
	[ 'PassEnv UnsetEnv SetEnv', 1, 11, 'virtual directory', 1.309 ] ];
return &make_directives($rv, $_[0], "mod_env");
}

sub edit_PassEnv_UnsetEnv_SetEnv
{
local($d, $e, @var, @mode, @val, $i, $rv);
foreach $d (@{$_[0]}, @{$_[1]}, @{$_[2]}) {
	if ($d->{'name'} ne "SetEnv") {
		foreach $e (@{$d->{'words'}}) {
			push(@var, $e);
			push(@mode, $d->{'name'} eq "PassEnv" ? 0 : 1);
			push(@val, "");
			}
		}
	else {
		push(@var, $d->{'words'}->[0]);
		push(@mode, 2);
		push(@val, $d->{'words'}->[1]);
		}
	}
push(@var, ""); push(@mode, 0); push(@val, "");
$rv = "<table border>\n".
      "<tr $tb> <td><b>Variable</b></td> <td><b>Value</b></td> </tr>\n";
for($i=0; $i<@var; $i++) {
	$rv .= "<tr $cb>\n";
	$rv .= "<td><input name=Env_var_$i size=20 value=\"$var[$i]\"></td>\n";
	$rv .= "<td>".&choice_input($mode[$i], "Env_mode_$i", 0,
	                            "Pass through,0", "Clear,1", "Set to..,2");
	$rv .= "<input name=Env_val_$i size=20 value=\"$val[$i]\"></td>\n";
	$rv .= "</tr>\n";
	}
$rv .= "</table>\n";
return (2, "Environment variables for CGI scripts", $rv);
}
sub save_PassEnv_UnsetEnv_SetEnv
{
local($i, $var, $mode, $val, @pa, @uns, @se);
for($i=0; defined($var = $in{"Env_var_$i"}); $i++) {
	$mode = $in{"Env_mode_$i"}; $val = $in{"Env_val_$i"};
	if ($var !~ /\S/ && $val !~ /\S/) { next; }
	$var =~ /^\S+$/ || &error("'$var' is not a valid variable name");
	if ($mode == 0) { push(@pa, $var); }
	elsif ($mode == 1) { push(@uns, $var); }
	elsif ($var !~ /^\S+$/) {
		&error("'$var' is not a valid variable value");
		}
	else { push(@se, "$var \"$val\""); }
	}
return ( \@pa, \@uns, \@se );
}

sub edit_PassEnvAll
{
return (1, "Pass all environment variables to CGIs",
	&choice_input($_[0]->{'value'}, "PassEnvAll",
		      "", "Yes,on", "No,off", "Default,"));
}
sub save_PassEnvAll
{
return &parse_choice("PassEnvAll");
}

1;

==> webmin-0.80.tar.gz: webmin-0.80/apache/mod_env.pl <==
# mod_env.pl
# Defines editors for passing variables to CGI scripts

sub mod_env_directives
{
local($rv);
$rv = [ [ 'PassEnv UnsetEnv SetEnv', 1, 11, 'virtual', -1.309 ],
	[ 'PassEnv UnsetEnv SetEnv', 1, 11, 'virtual directory', 1.309 ] ];
return &make_directives($rv, $_[0], "mod_env");
}

sub edit_PassEnv_UnsetEnv_SetEnv
{
local($d, $e, @var, @mode, @val, $i, $rv);
foreach $d (@{$_[0]}, @{$_[1]}, @{$_[2]}) {
	if ($d->{'name'} ne "SetEnv") {
		foreach $e (@{$d->{'words'}}) {
			push(@var, $e);
			push(@mode, $d->{'name'} eq "PassEnv" ? 0 : 1);
			push(@val, "");
			}
		}
	else {
		push(@var, $d->{'words'}->[0]);
		push(@mode, 2);
		push(@val, $d->{'words'}->[1]);
		}
	}
push(@var, ""); push(@mode, 0); push(@val, "");
$rv = "<table border>\n".
      "<tr $tb> <td><b>$text{'mod_env_0'}</b></td> <td><b>$text{'mod_env_1'}</b></td> </tr>\n";
for($i=0; $i<@var; $i++) {
	$rv .= "<tr $cb>\n";
	$rv .= "<td><input name=Env_var_$i size=20 value=\"$var[$i]\"></td>\n";
	$rv .= "<td>".&choice_input($mode[$i], "Env_mode_$i", 0,
	                            "$text{'mod_env_2'},0", "$text{'mod_env_3'},1", "$text{'mod_env_4'},2");
	$rv .= "<input name=Env_val_$i size=20 value=\"$val[$i]\"></td>\n";
	$rv .= "</tr>\n";
	}
$rv .= "</table>\n";
return (2, "$text{'mod_env_5'}", $rv);
}
sub save_PassEnv_UnsetEnv_SetEnv
{
local($i, $var, $mode, $val, @pa, @uns, @se);
for($i=0; defined($var = $in{"Env_var_$i"}); $i++) {
	$mode = $in{"Env_mode_$i"}; $val = $in{"Env_val_$i"};
	if ($var !~ /\S/ && $val !~ /\S/) { next; }
	$var =~ /^\S+$/ || &error(&text('mod_env_10', $var));
	if ($mode == 0) { push(@pa, $var); }
	elsif ($mode == 1) { push(@uns, $var); }
	elsif ($var !~ /^\S+$/) {
		&error(&text('mod_env_11', $var));
		}
	else { push(@se, "$var \"$val\""); }
	}
return ( \@pa, \@uns, \@se );
}

sub edit_PassEnvAll
{
return (1, "$text{'mod_env_6'}",
	&choice_input($_[0]->{'value'}, "PassEnvAll",
		      "", "$text{'mod_env_7'},on", "$text{'mod_env_8'},off", "$text{'mod_env_9'},"));
}
sub save_PassEnvAll
{
return &parse_choice("PassEnvAll");
}

1;
